import express, { Router, Request, Response } from 'express'
import { ProductService, productService } from '../services/products'
import { ProductServicePg, productServicePg } from '../services/productsPg'
import multer from 'multer'
// import {nanoid} from 'nanoid'
// const {nanoid} = require('nanoid')
import { config } from '../index.config'
// import path from 'path'

const storage = multer.diskStorage({
    destination(req, file, callback) {
        callback(null, 
            config.filePath)
    },
    filename(req, file, callback) {
        callback(null, 
            file.originalname)
    },
})

const upload = multer({storage})

export class ProductsController {
    private router: Router
    private service: ProductService | ProductServicePg

    constructor() {
        this.router = express.Router()
        this.router.get('/', this.getProducts)
        this.router.get('/:id', this.getProductById)
        this.router.post('/', upload.single('image'), this.addProduct)
        switch(process.env.DB) {
            case 'file':
                this.service = productService
                break
            case 'postgres':
                this.service = productServicePg
                break
            default:
                this.service = productServicePg
        }
    }

    public getRouter = (): Router => {
        return this.router
    }

    private getProducts = async (req: Request, res: Response): Promise<void> => {
        const response = await this.service.getProducts()
        res.send(response)
    }

    private getProductById = async (req: Request, res: Response): Promise<void> => {
        const response = await this.service.getProductById(req.params.id)
        res.send(response)
    }

    private addProduct = async (req: Request, res: Response): Promise<void> => {
        console.log('REQ FILE****: ', req.file)
        const product = req.body
        product.image = req.file ? req.file.filename : ''
        const response = await this.service.addProduct(product)
        res.send(response)
    }
}