import { EStatuses } from "../enums/EStatuses"
import IProduct from "../interfaces/IProduct"
import IProductDto from "../interfaces/IProductDto"
import IResponse from "../interfaces/IResponse"
import { db } from "../repository/fileDB"

export class ProductService {
    public getProducts = (): IResponse => {
        try {
            const data = db.getItems()
            const response: IResponse = {
                status: EStatuses.OK,
                result: data,
                message: 'Products found'
            }
            return response
        } catch (err: unknown) {
            const error = err as Error
            const response: IResponse = {
                status: EStatuses.NOT_OK,
                result: undefined,
                message: error.message
            }
            return response
        }
    }

    public getProductById = (id: string): IResponse => {
        try {
            const data: IProduct | undefined = db.getItemById(id)
            const response: IResponse = {
                status: EStatuses.OK,
                result: data,
                message: ''
            }
            return response
        } catch (err: unknown) {
            const error = err as Error
            const response: IResponse = {
                status: EStatuses.NOT_OK,
                result: undefined,
                message: error.message
            }
            return response
        }
    }

    public addProduct = (product: IProductDto): IResponse => {
        try {
            const data: IProduct | undefined = db.addItem(product)
            const response: IResponse = {
                status: EStatuses.OK,
                result: data,
                message: ''
            }
            return response
        } catch (err: unknown) {
            const error = err as Error
            const response: IResponse = {
                status: EStatuses.NOT_OK,
                result: undefined,
                message: error.message
            }
            return response
        }
    }

}

export const productService = new ProductService()